.. If you created a package, create one automodule per module in the package.

.. automodule:: adafruit_ble_adafruit.accelerometer_service
   :members:

.. automodule:: adafruit_ble_adafruit.adafruit_service
   :members:

.. automodule:: adafruit_ble_adafruit.addressable_pixel_service
   :members:

.. automodule:: adafruit_ble_adafruit.barometric_pressure_service
   :members:

.. automodule:: adafruit_ble_adafruit.button_service
   :members:

.. automodule:: adafruit_ble_adafruit.color_sensor_service
   :members:

.. automodule:: adafruit_ble_adafruit.gesture_service
   :members:

.. automodule:: adafruit_ble_adafruit.gyroscope_service
   :members:

.. automodule:: adafruit_ble_adafruit.humidity_service
   :members:

.. automodule:: adafruit_ble_adafruit.light_sensor_service
   :members:

.. automodule:: adafruit_ble_adafruit.magnetometer_service
   :members:

.. automodule:: adafruit_ble_adafruit.microphone_service
   :members:

.. automodule:: adafruit_ble_adafruit.proximity_service
   :members:

.. automodule:: adafruit_ble_adafruit.quaternion_service
   :members:

.. automodule:: adafruit_ble_adafruit.temperature_service
   :members:

.. automodule:: adafruit_ble_adafruit.tone_service
   :members:
